@@ -395,7 +395,7 @@ def build_json_files():
     set_data = build_set_data(relic_list)
     relic_data = build_relic_data(relic_list, set_data)
 
-    return json.loads(json.dumps(relic_data)), json.loads(json.dumps(set_data)), json.loads(json.dumps(relic_list))
+    return json.loads(json.dumps(relic_data)), json.loads(json.dumps(set_data))
 
 
 def get_price_data():
